"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.handler = void 0;
require("dotenv/config");
const client_s3_1 = require("@aws-sdk/client-s3");
const child_process_1 = require("child_process");
const fs_1 = require("fs");
const path_1 = require("path");
const handler = async () => {
    try {
        console.info('Function init, backing up db...');
        const backupPath = await backup();
        console.info('Backup created, uploading to S3...');
        await upload(backupPath);
        console.info('Backup uploaded to S3, done.');
    }
    catch (error) {
        console.error(error);
        throw error;
    }
};
exports.handler = handler;
async function backup() {
    (0, fs_1.mkdirSync)('/tmp/backup', { recursive: true });
    return new Promise((resolve, reject) => {
        const [date] = new Date().toISOString().split('.');
        const dbHost = process.env.DB_HOST;
        const dbUser = process.env.DB_USER;
        const dbPort = process.env.DB_PORT;
        const dbPassword = process.env.DB_PASSWORD;
        const dbName = process.env.DB_NAME;
        const mysqlDumpPath = (0, path_1.join)(__dirname, 'mysqldump');
        const outPath = `/tmp/${dbName}__${date}.sql`;
        const command = `${mysqlDumpPath} -h ${dbHost} -P ${dbPort} -u ${dbUser} -p${dbPassword} --verbose ${dbName} > ${outPath}`;
        (0, child_process_1.exec)(command, (error, stdout, stderr) => {
            if (error) {
                console.error(`exec error: ${error}`);
                reject(error);
                return;
            }
            console.info(`stdout: ${stdout}`);
            console.info(`stderr: ${stderr}`);
            resolve(outPath);
        });
    });
}
async function upload(path) {
    const data = (0, fs_1.readFileSync)(path);
    const client = new client_s3_1.S3Client({
        region: process.env.BUCKET_REGION,
    });
    const fileName = path.replace('/tmp/', '');
    const command = new client_s3_1.PutObjectCommand({
        Bucket: process.env.BUCKET_NAME,
        Key: fileName,
        Body: data,
        ContentType: 'application/zip',
    });
    await client.send(command);
}
